<?php
/**
 * Fetchify
 *
 * @author       	ClearCourse Business Services Ltd t/a Fetchify
 * @link            https://fetchify.com
 * @copyright  		Copyright (c) 2022, ClearCourse Business Services Ltd
 * @version			4.2.0
**/

class ControllerExtensionModuleCraftyGlobal extends Controller {
	private $error = array();
	
	public function index() {
		// Loading the language file of craftyGlobal
		$this->load->language('extension/module/craftyGlobal');

		// Set the title of the page to the heading title in the Language file i.e., Hello World
		$this->document->setTitle($this->language->get('heading_title'));

		// Load the Setting Model  (All of the OpenCart Module & General Settings are saved using this Model )
		$this->load->model('setting/setting');

		// Restore autocomplete status from previous version
		if ((bool)$this->config->get('module_craftyGlobal_status') && is_null($this->config->get('module_craftyGlobal_autocomplete_status'))) {
			$initialConfig = $this->model_setting_setting->getSetting('module_craftyGlobal');
			$initialConfig['module_craftyGlobal_autocomplete_status'] = '1';

			$this->model_setting_setting->editSetting('module_craftyGlobal', $initialConfig);

			$this->response->redirect($this->url->link('extension/module/craftyGlobal', 'user_token=' . $this->session->data['user_token'], true));
		}

		// Start If: Validates and check if data is coming by save (POST) method
		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
			// Check if a product has been enabled and set status accordingly
			$this->request->post['module_craftyGlobal_status'] = $this->hasEnabledProduct();

			// Store settings in database
			$this->model_setting_setting->editSetting('module_craftyGlobal', $this->request->post);

			// Display the success text on data save
			$this->session->data['success'] = $this->language->get('text_success');

			// Redirect to the Module Listing
			$this->response->redirect($this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module', true));
		}

		// load all the texts!
		$ccTextValues = array(
			'heading_title',
			'text_module',
			'text_edit',
			'text_success',
			'text_extension',
			'error_permission',
			'label_access_token',
			'label_postcode_status',
			'label_autocomplete_status',
			'label_ambient',
			'label_mode',
			'label_country_button',
			'label_country_placeholder',
			'label_default_placeholder',
			'label_generic_error',
			'label_search_label',
			'label_showLogo',
			'label_hideFields',
			'label_no_results',
			'label_use_first_line',
			'label_phone_status',
			'label_phone_can_correct',
			'label_phone_allowed_type',
			'label_email_status',
			'label_email_allow_high_risk'
		);
		$data['craftyAdminLabels'] = array();
		foreach ($ccTextValues as $elem) {
			$data['craftyAdminLabels'][$elem] = $this->language->get($elem);
		}

		//Load all the settings from config!
		$ccVariableValues = array(
			'module_craftyGlobal_access_token',
			'module_craftyGlobal_postcode_status',
			'module_craftyGlobal_autocomplete_status',
			'module_craftyGlobal_mode',
			'module_craftyGlobal_ambient',
			'module_craftyGlobal_country_button',
			'module_craftyGlobal_country_placeholder',
			'module_craftyGlobal_default_placeholder',
			'module_craftyGlobal_generic_error',
			'module_craftyGlobal_no_results',
			'module_craftyGlobal_search_label',
			'module_craftyGlobal_showLogo',
			'module_craftyGlobal_hideFields',
			'module_craftyGlobal_use_first_line',
			'module_craftyGlobal_phone_status',
			'module_craftyGlobal_phone_can_correct',
			'module_craftyGlobal_phone_allowed_type',
			'module_craftyGlobal_email_status',
			'module_craftyGlobal_email_allow_high_risk'
		);
		$data['craftyValues'] = array();
		foreach ($ccVariableValues as $elem) {
			$data['craftyValues'][$elem] = $this->loadFromConfig($data, $elem);
		}

		//For Admin Panel locale_lookup
		$configValues= array(
			'access_token',
			'postcode_status',
			'autocomplete_status',
			'ambient',
			'mode',
			'default_placeholder',
			'country_button',
			'country_placeholder',
			'search_label',
			'generic_error',
			'no_results',
			'showLogo',
			'hideFields',
			'use_first_line',
			'phone_status',
			'phone_can_correct',
			'phone_allowed_type',
			'email_status',
			'email_allow_high_risk'
		);
		$data['craftyGlobalConfig']= array();
		foreach ($configValues as $crafty) {
			$data['craftyGlobalConfig'][$crafty] = $this->config->get('module_craftyGlobal_'.$crafty);
		}

		// This Block returns the warning if any
		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}

		// This Block returns the error code if any
		if (isset($this->error['code'])) {
			$data['error_code'] = $this->error['code'];
		} else {
			$data['error_code'] = '';
		}

		// Making of Breadcrumbs to be displayed on site
		$data['breadcrumbs'] = array();
		$data['breadcrumbs'][] = array(
			'text'	  => $this->language->get('text_home'),
			'href'	  => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], true)
		);
		$data['breadcrumbs'][] = array(
			'text'	  => $this->language->get('text_extensions'),
			'href'	  => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module', true)
		);
		$data['breadcrumbs'][] = array(
			'text'	  => $this->language->get('heading_title'),
			'href'	  => $this->url->link('extension/module/craftyGlobal', 'user_token=' . $this->session->data['user_token'], true)
		);

		$data['action'] = $this->url->link('extension/module/craftyGlobal', 'user_token=' . $this->session->data['user_token'], true); // URL to be directed when the save button is pressed
		$data['cancel'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module', true); // URL to be redirected when cancel button is pressed

		if (isset($this->request->post['module_craftyGlobal_status'])) {
			$data['module_craftyGlobal_status'] = $this->request->post['module_craftyGlobal_status'];
		} else {
			$data['module_craftyGlobal_status'] = $this->config->get('module_craftyGlobal_status');
		}

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');
		$this->response->setOutput($this->load->view('extension/module/craftyGlobal', $data));
	}

	protected function validate() {
		if (!$this->user->hasPermission('modify', 'extension/module/craftyGlobal')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}
		return !$this->error;
	}

	private function hasEnabledProduct() {
		$request = $this->request->post;
		$products = array('postcode', 'autocomplete', 'phone', 'email');

		foreach ($products as $product) {
			if ($request['module_craftyGlobal_' . $product . '_status'] == '1') {
				return '1';
			}
		}

		return '0';
	}

	private function loadFromConfig(&$data, $key) {
		$data[$key] = $this->config->get($key);
	}
}
