<?php
/**
 * Fetchify
 *
 * @author       	ClearCourse Business Services Ltd t/a Fetchify
 * @link            https://fetchify.com
 * @copyright  		Copyright (c) 2022, ClearCourse Business Services Ltd
 * @version			2.1.0
**/

class ControllerModuleCraftyGlobal extends Controller {
	private $error = array();
	public function index() {
		// Loading the language file of craftyGlobal
		$this->load->language('module/craftyGlobal');

		// Set the title of the page to the heading title in the Language file i.e., Hello World
		$this->document->setTitle($this->language->get('heading_title'));

		// Load the Setting Model  (All of the OpenCart Module & General Settings are saved using this Model )
		$this->load->model('setting/setting');

		// Restore autocomplete status from previous version
		if ((bool)$this->config->get('craftyGlobal_status') && is_null($this->config->get('craftyGlobal_autocomplete_status'))) {
			$initialConfig = $this->model_setting_setting->getSetting('craftyGlobal');
			$initialConfig['craftyGlobal_autocomplete_status'] = '1';

			$this->model_setting_setting->editSetting('craftyGlobal', $initialConfig);

			$this->response->redirect($this->url->link('module/craftyGlobal', 'token=' . $this->session->data['token'], 'SSL'));
		}

		// Start If: Validates and check if data is coming by save (POST) method
		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
			// Check if a product has been enabled and set status accordingly
			$this->request->post['craftyGlobal_status'] = $this->hasEnabledProduct();

			// Parse all the coming data to Setting Model to save it in database.
			$this->model_setting_setting->editSetting('craftyGlobal', $this->request->post);

			// To display the success text on data save
			$this->session->data['success'] = $this->language->get('text_success');

			// Redirect to the Module Listing
			$this->response->redirect($this->url->link('module/craftyGlobal', 'token=' . $this->session->data['token'], 'SSL'));
		}

		// load all the texts!
		$ccTextValues = array(
			'heading_title',
			'text_edit',
			'text_content_top',
			'text_content_bottom',
			'text_column_left',
			'text_column_right',
			'entry_layout',
			'entry_position',
			'entry_sort_order',
			'button_save',
			'button_cancel',
			'button_add_module',
			'button_remove',
			'label_access_token',
			'label_postcode_status',
			'label_autocomplete_status',
			'label_mode',
			'label_ambient',
			'label_accent',
			'label_showLogo',
			'label_hideFields',
			'label_default_placeholder',
			'label_country_button',
			'label_country_placeholder',
			'label_generic_error',
			'label_no_results',
			'label_search_label',
			'label_useLine1',
			'label_phone_status',
			'label_phone_can_correct',
			'label_phone_allowed_type',
			'label_email_status',
			'label_email_allow_high_risk'
		);
		$data['craftyAdminLabels'] = array();
		foreach ($ccTextValues as $elem) {
			$data['craftyAdminLabels'][$elem] = $this->language->get($elem);
		}

		//Load all the settings from config!
		$ccVariableValues = array(
			'craftyGlobal_access_token',
			'craftyGlobal_postcode_status',
			'craftyGlobal_autocomplete_status',
			'craftyGlobal_mode',
			'craftyGlobal_ambient',
			'craftyGlobal_accent',
			'craftyGlobal_showLogo',
			'craftyGlobal_hideFields',
			'craftyGlobal_default_placeholder',
			'craftyGlobal_country_button',
			'craftyGlobal_country_placeholder',
			'craftyGlobal_generic_error',
			'craftyGlobal_no_results',
			'craftyGlobal_search_label',
			'craftyGlobal_useLine1',
			'craftyGlobal_phone_status',
			'craftyGlobal_phone_can_correct',
			'craftyGlobal_phone_allowed_type',
			'craftyGlobal_email_status',
			'craftyGlobal_email_allow_high_risk'
		);
		$data['craftyValues'] = array();
		foreach ($ccVariableValues as $elem) {
			$data['craftyValues'][$elem] = $this->loadFromConfig($data, $elem);
		}

		//For Admin Panel locale_lookup
		$configValues= array(
			'access_token',
			'postcode_status',
			'autocomplete_status',
			'mode',
			'ambient',
			'accent',
			'showLogo',
			'hideFields',
			'default_placeholder',
			'country_button',
			'country_placeholder',
			'generic_error',
			'no_results',
			'search_label',
			'useLine1',
			'phone_status',
			'phone_can_correct',
			'phone_allowed_type',
			'email_status',
			'email_allow_high_risk'
		);
		$data['craftyGlobalConfig']= array();
		foreach ($configValues as $crafty) {
			$data['craftyGlobalConfig'][$crafty] = html_entity_decode($this->config->get('craftyGlobal_'.$crafty));
		}

		// This Block returns the warning if any
		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}

		// This Block returns the error code if any
		if (isset($this->error['code'])) {
			$data['error_code'] = $this->error['code'];
		} else {
			$data['error_code'] = '';
		}

		// Making of Breadcrumbs to be displayed on site
		$data['breadcrumbs'] = array();
		$data['breadcrumbs'][] = array(
			'text'	  => $this->language->get('text_home'),
			'href'	  => $this->url->link('common/home', 'token=' . $this->session->data['token'], 'SSL'),
			'separator' => false
		);
		$data['breadcrumbs'][] = array(
			'text'	  => $this->language->get('text_module'),
			'href'	  => $this->url->link('extension/module', 'token=' . $this->session->data['token'], 'SSL'),
			'separator' => ' :: '
		);
		$data['breadcrumbs'][] = array(
			'text'	  => $this->language->get('heading_title'),
			'href'	  => $this->url->link('module/craftyGlobal', 'token=' . $this->session->data['token'], 'SSL'),
			'separator' => ' :: '
		);

		$data['action'] = $this->url->link('module/craftyGlobal', 'token=' . $this->session->data['token'], 'SSL'); // URL to be directed when the save button is pressed
		$data['cancel'] = $this->url->link('extension/module', 'token=' . $this->session->data['token'], 'SSL'); // URL to be redirected when cancel button is pressed
		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');
		$this->response->setOutput($this->load->view('module/craftyGlobal.tpl', $data));
	}

	protected function validate() {
		if (!$this->user->hasPermission('modify', 'module/craftyGlobal')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}
		return !$this->error;
	}

	private function hasEnabledProduct() {
		$request = $this->request->post;
		$products = array('postcode','autocomplete', 'phone', 'email');

		foreach ($products as $product) {
			if ($request['craftyGlobal_' . $product . '_status'] == '1') {
				return '1';
			}
		}

		return '0';
	}

	private function loadFromConfig(&$data, $key) {
		$data[$key] = $this->config->get($key);
	}
}
